
# This file was generated by 'versioneer.py' (0.20.dev0) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2021-12-16T01:41:50+0000",
 "dirty": false,
 "error": null,
 "full-revisionid": "107219b2e5d44e10d7589272767ad27c4ac6da41",
 "version": "0.15.4"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
